<?php
/**
 * $Horde: trean/browse.php,v 1.42 2005/01/06 03:00:31 ben Exp $
 *
 * Copyright 2002-2005 Mike Cochrane <mike@graftonhall.co.nz>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 */

@define('TREAN_BASE', dirname(__FILE__));
require_once TREAN_BASE . '/lib/base.php';
require_once 'Horde/Tree.php';
require_once 'Horde/Template.php';

/* The URL that the category tree and categories list will be linking to. */
$base_url = 'browse.php';

/* Number of columns to display. */
$cols = $prefs->getValue('browse_columns');

/* Get bookmarks to display. */
$category_id = Util::getFormData('category_id', DATATREE_ROOT);
$category = &$trean_bookmarks->getCategory($category_id);
$bookmarks = $category->listBookmarks();

/* Get full categories tree to display. */
$category_tree = Trean::listCategories(DATATREE_ROOT, false);

/* Set up the tree. */
$params = array('icondir' => $registry->getImageDir('horde') . '/tree',
                'icon' => 'folder.png',
                'iconopen' => 'folderopen.png');

$tree = &Horde_Tree::factory('category_tree', 'javascript');
$tree->setOption(array('class' => 'item', 'alternate' => true));
$expandTree = $prefs->getValue('expand_tree');

foreach ($category_tree as $node_id => $node_val) {
    if ($node_id != DATATREE_ROOT) {
        /* If a non-root node, get parent and set base indent to 1. */
        $parent_id = $trean_bookmarks->getName($trean_bookmarks->getParent($node_val));
        $indent = 1 + substr_count($node_id, ':');
        $label = $node_val->get('name');
        $expanded = ($expandTree == 'all') || ($parent_id == DATATREE_ROOT && $expandTree == 'first');
    } else {
        /* Root node, it has no parent and no base indent. */
        $node_id = DATATREE_ROOT;
        $parent_id = null;
        $indent = 0;
        $label = _("My Bookmarks");
        $expanded = ($prefs->getValue('expand_tree') == 'none') ? false : true;
    }

    /* Selected or not? */
    $class = ($node_id == $category_id) ? array('class' => 'selected') : array();

    /* The clickable url for each node. */
    $params['url'] = Util::addParameter(Horde::applicationUrl('browse.php'), 'category_id', $trean_bookmarks->getId($node_id));

    /* Add the node and add the node params. */
    $tree->addNode($node_id, $parent_id, $label,
                   $indent, $expanded, $params + $class);
}

$template = &new Horde_Template();
$template->setOption('gettext', true);
$template->set('category_tree', Util::bufferOutput(array($tree, 'renderTree')));

$title = _("Browse");
require TREAN_TEMPLATES . '/common-header.inc';
require TREAN_TEMPLATES . '/menu.inc';
require TREAN_TEMPLATES . '/browse/javascript.inc';
require TREAN_TEMPLATES . '/browse/header.inc';
echo $template->fetch(TREAN_TEMPLATES . '/browse/browse.html');

require TREAN_TEMPLATES . '/browse/bookmarks.inc';
require TREAN_TEMPLATES . '/browse/footer.inc';
require $registry->get('templates', 'horde') . '/common-footer.inc';
