<?php
/**
 * $Horde: trean/data.php,v 1.32 2005/01/03 14:35:34 jan Exp $
 *
 * Copyright 2002-2005 Mike Cochrane <mike@graftonhall.co.nz>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 */

@define('TREAN_BASE', dirname(__FILE__));
require_once TREAN_BASE . '/lib/base.php';

switch (Util::getFormData('actionID')) {
case 'import':
    $result = Browser::wasFileUploaded('import_file');
    if (is_a($result, 'PEAR_Error')) {
        $notification->push($res->getMessage(), 'horde.error');
        break;
    }

    $target = Util::getFormData('target', DATATREE_ROOT);
    $root = &$trean_bookmarks->getCategory($target);
    if (is_a($root, 'PEAR_Error')) {
        $notification->push($root, 'horde.error');
        break;
    }

    $lines = file($_FILES['import_file']['tmp_name']);

    $folders = 0;
    $bookmarks = 0;
    $category = $root;
    $parent = $root;
    $bookmark = null;

    foreach ($lines as $line) {
        if (strpos($line, '<DT><H3') !== false) {
            /* Start of a category. */
            $parent = $category;

            if ($parent->getId() == DATATREE_ROOT) {
                $category = &$trean_bookmarks->newCategory(md5(uniqid(mt_rand())), array('name' => trim(strip_tags($line))));
                $trean_bookmarks->addCategory($category);
            } else {
                $category_id = $category->addCategory(array('name' => trim(strip_tags($line))));
                $category = &$trean_bookmarks->getCategory($category_id);
            }

            $folders++;
        } elseif (strpos($line, '</DL>') !== false) {
            /* End of a category. */
            $category = $parent;

        } elseif (preg_match("/<DT><A HREF=\"*(.*?)\".*>(.*)<\/A>/", $line, $temp)) {
            /* A bookmark. */
            $properties = array();
            $properties['url'] = trim($temp[1]);
            $properties['title'] = trim($temp[2]);
            $properties['description'] = '';
            $bookmark_id = $category->addBookmark($properties);
            $bookmark = &$trean_bookmarks->getBookmark($bookmark_id);
            $bookmarks++;
        } elseif (strpos($line, '<DD>') !== false) {
            if (!is_null($bookmark)) {
                $bookmark->set('description', trim(strip_tags($line)), true);
            }
        }
        
    }

    $notification->push(sprintf(_("%d Folders and %d Bookmarks imported."), $folders, $bookmarks), 'horde.success');

    $url = Util::addParameter('browse.php', 'category_id', $root->getId());
    header('Location: ' . Horde::applicationUrl($url, true));
    exit;

case 'export':
    $output = '<!DOCTYPE NETSCAPE-Bookmark-file-1>
    <!--This is an automatically generated file.
    It will be read and overwritten.
    Do Not Edit! -->
    <Title>Bookmarks</Title>
    <H1>Bookmarks</H1>' . "\n";

    $output .= '<DL><p>' . "\n";
    $tree = Trean::listCategories();
    foreach ($tree as $category => $subtree) {
        $output .= export($category, $subtree, 1);
    }
    $output .= '</DL><p>' . "\n";

    $browser->downloadHeaders('bookmarks.html', 'text/html', false, strlen($output));
    echo $output;
    exit;
}

$title = _("Import Bookmarks");
require TREAN_TEMPLATES . '/common-header.inc';
require TREAN_TEMPLATES . '/menu.inc';
require TREAN_TEMPLATES . '/data/import.inc';
require $registry->get('templates', 'horde') . '/common-footer.inc';

function export($cat, $tree, $depth)
{
    global $trean_bookmarks;

    $cat = &$trean_bookmarks->getCategory($cat);
    $name = $cat->get('name');

    $output  = str_repeat(' ', $depth * 4) . '<DT><H3 FOLDED ADD_DATE="' . time() .  '">' . $name . '</H3>' . "\n";
    $output .= str_repeat(' ', $depth * 4) . '<DL><p>' . "\n";

    $bookmarks = $cat->listBookmarks();
    foreach ($bookmarks as $id => $name) {
        $bookmark = &$trean_bookmarks->getBookmark($id);
        $output .= str_repeat(' ', ($depth + 1) * 4) . '<DT><A HREF="' . $bookmark->get('url') . '" ADD_DATE="'. time() . '" LAST_VISIT="0" LAST_MODIFIED="0">';
        $output .= $bookmark->get('title') . '</A>' . "\n";
    }

    if (is_array($tree)) {
        foreach ($tree as $cat => $subtree) {
            $output .= export($cat, $subtree, $depth + 1);
        }
    }

    return $output . str_repeat(' ', $depth * 4) . '</DL><p>'  . "\n";
}
