<?php

$block_name = _("Bookmarks");

/**
 * Implementation of Horde_Block api to show bookmarks.
 *
 * $Horde: trean/lib/Block/bookmarks.php,v 1.19 2005/01/06 19:02:08 chuck Exp $
 *
 * Copyright 2004-2005 Joel Vandal <jvandal@infoteck.qc.ca>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 *
 * @author  Joel Vandal <jvandal@infoteck.qc.ca>
 * @since   Trean 1.0
 * @package Horde_Block
 */
class Horde_Block_Trean_bookmarks extends Horde_Block {

    var $_app = 'trean';
    var $_category = null;

    function _params()
    {
        require_once dirname(__FILE__) . '/../base.php';

        /* Get categories to display. */
        $values[DATATREE_ROOT] = _("My Bookmarks");
        $categories = &Trean::listCategories();
        foreach ($categories as $key => $category) {
            if ($key == DATATREE_ROOT) {
                continue;
            }
            $values[$category->getId()] = $category->get('name');
        }

        return array('category' => array('name' => _("Category"),
                                         'type' => 'enum',
                                         'default' => DATATREE_ROOT,
                                         'values' => $values),
                     'template' => array('name' => _("Template"),
                                         'type' => 'enum',
                                         'default' => '1line',
                                         'values' => array('standard' => _("3 Line"),
                                                           '2line' => _("2 Line"),
                                                           '1line' => _("1 Line"))));
    }

    /**
     * The title to go in this block.
     *
     * @return string   The title text.
     */
    function _title()
    {
        global $registry;

        $category = &$this->_getCategory();
        if (is_a($category, 'PEAR_Error')) {
            $name = $registry->get('name');
        } else {
            $name = $category->get('name');
            if (!$name) {
                $name = _("My Bookmarks");
            }
        }

        return Horde::link(Horde::url($registry->getInitialPage(), true), $name, 'header') . $name . '</a> :: '
            . Horde::link(Horde::applicationUrl('add.php', true), _("New Bookmark"), 'smallheader') . Horde::img('add.png', _("New Bookmark"), null, Horde::url($registry->getImageDir(), true, -1)) . _("New Bookmark") . '</a>';
    }

    /**
     * The content to go in this block.
     *
     * @return string   The content
     */
    function _content()
    {
        require_once dirname(__FILE__) . '/../base.php';

        $template = TREAN_TEMPLATES . '/block/' . $this->_params['template'] . '.inc';

        $category = &$this->_getCategory();
        if (is_a($category, 'PEAR_Error')) {
            return $category;
        }

        $html = '';
        $count = 0;
        $bookmarks = &$GLOBALS['trean_bookmarks']->listBookmarks($category->getName());
        foreach ($bookmarks as $bookmark) {
            ob_start();
            require $template;
            $html .= '<div class="item' . ($count++ % 2) . '">' . ob_get_contents() . '</div>';
            ob_end_clean();
        }

        if ($count == 0) {
            return '<div><i>' . _("No bookmarks to display") . '</i></div>';
        }

        return $html;
    }

    function &_getCategory()
    {
        require_once dirname(__FILE__) . '/../base.php';

        if ($this->_category == null) {
            $this->_category = &$GLOBALS['trean_bookmarks']->getCategory($this->_params['category']);
        }

        return $this->_category;
    }

}
