<?php
/**
 * Trean Base Class.
 *
 * $Horde: trean/lib/Trean.php,v 1.44 2005/01/06 19:02:08 chuck Exp $
 *
 * Copyright 2002-2005 Mike Cochrane <mike@graftonhall.co.nz>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 *
 * @author  Mike Cochrane <mike@graftonhall.co.nz>
 * @package Trean
 */
class Trean {

    /**
     * List categories.
     *
     * @return array  A list of categories.
     */
    function listCategories($parent = DATATREE_ROOT, $no_root = true, $allLevels = true)
    {
        static $lists;
        if (is_null($lists)) {
            $lists = array();
        }

        $key = serialize(array($parent, $no_root, $allLevels));
        if (!isset($lists[$key])) {
            $pcat = $GLOBALS['trean_bookmarks']->getName($parent);
            if (is_a($pcat, 'PEAR_Error')) {
                $GLOBALS['notification']->push(_("Category does not exist."), 'horde.error');
                return array();
            }

            $lists[$key] = &$GLOBALS['trean_bookmarks']->listCategories($parent, $allLevels);
            if ($parent == DATATREE_ROOT) {
                $lists[$key][DATATREE_ROOT] = _("My Bookmarks");
            }

            if (false && $no_root) {
                unset($lists[$key][$parent]);
            }
        }

        return $lists[$key];
    }

    /**
     * List all bookmarks in $parent or any of its children..
     *
     * @return array  A list of categories.
     */
    function listAllBookmarks($parent = DATATREE_ROOT, $depth = -1)
    {
        static $lists;
        if (is_null($lists)) {
            $lists = array();
        }

        $key = serialize(array($parent, $depth));
        if (!isset($lists[$key])) {
            $pcat = $GLOBALS['trean_bookmarks']->getName($parent);
            if (is_a($pcat, 'PEAR_Error')) {
                $GLOBALS['notification']->push(_("Category does not exist."), 'horde.error');
                return array();
            }

            $result = $GLOBALS['trean_bookmarks']->_datatree->get(DATATREE_FORMAT_FLAT, $pcat, true, _("My Bookmarks"), $depth);
            if (is_a($result, 'PEAR_Error')) {
                $GLOBALS['notification']->push($result, 'horde.error');
                return array();
            }

            $lists[$key] = array();
            foreach ($result as $id => $name) {
                if ($id == $parent) {
                    continue;
                }

                $object = &$GLOBALS['trean_bookmarks']->getBookmark($id);
                if ($object->get('type') == 'category') {
                    continue;
                }

                $lists[$key][$id] = $name;
            }
        }

        return $lists[$key];
    }

    function listCategoryLevel($parent = DATATREE_ROOT)
    {
        return $GLOBALS['trean_bookmarks']->extractOneLevel($parent);
    }

    function getCategoryParent($category)
    {
        return $GLOBALS['trean_bookmarks']->getParent($category);
    }

    function getName($category)
    {
        return $GLOBALS['trean_bookmarks']->getName($category);
    }

    /**
     * This generates the body of a &lt;select&gt; form input to select a
     * category. The &lt;select&gt; and &lt;/select&gt; tags are NOT included
     * in the output of this function.
     *
     * @param optional string $selected  The category to have selected by
     *                                   default. Defaults to the first option
     *                                   in the list.
     *
     * @return string  A string containing <option> elements for each category
     *                 in the list.
     */
    function categorySelect($selected = DATATREE_ROOT)
    {
        $options = '';
        $tree = &Trean::listCategories();
        foreach ($tree as $key => $category) {
            if ($key != DATATREE_ROOT) {
                $indent = substr_count($key, ':') + 1;
                $id = $category->getId();
                $sel = ($selected == $id) ? ' selected="selected"' : '';
                $options .= '<option value="' . $id . '"' . $sel . '>' . str_repeat('&nbsp;&nbsp;', $indent) . $category->get('name') . '</option>';
            } else {
                $sel = ($selected == DATATREE_ROOT) ? ' selected="selected"' : '';
                $options .= '<option value="' . DATATREE_ROOT . '"' . $sel . '>' . _("My Bookmarks") . '</option>';
            }
        }

        return $options;
    }

    /**
     * Build Trean's list of menu items.
     *
     * @access public
     */
    function getMenu($returnType = 'object')
    {
        global $conf, $registry;

        require_once 'Horde/Menu.php';

        $menu = &new Menu();
        $menu->add(Horde::applicationUrl('browse.php'), _("Browse"), 'trean.png', null, null, null, basename($_SERVER['PHP_SELF']) == 'index.php' ? 'current' : null);
        $menu->add(Horde::applicationUrl('add.php'), _("Add"), 'add.png');
        $menu->add(Horde::applicationUrl('search.php'), _("Search"), 'search.png', $registry->getImageDir('horde'));

        /* Import/Export. */
        if ($conf['menu']['import_export']) {
            $menu->add(Horde::applicationUrl('data.php'), _("Import/Export"), 'data.png', $registry->getImageDir('horde'));
        }

        if ($returnType == 'object') {
            return $menu;
        } else {
            return $menu->render();
        }
    }

}
