#!/usr/local/bin/php
<?php
/**
 * $Horde: trean/scripts/upgrades/2004-12-14_use_datatree_relationships.php,v 1.2 2004/12/14 23:56:39 ben Exp $
 *
 * This is a script to migrate bookmarks to better use the DataTree structure.
 */

/**
 ** Set this to true if you want DB inserts done.
 **/
$live = false;

// No auth.
@define('AUTH_HANDLER', true);

// Find the base file path of Horde.
@define('TREAN_BASE', dirname(__FILE__) . '/../..');

// Do CLI checks and environment setup first.
require_once TREAN_BASE . '/lib/base.php';
require_once 'Horde/CLI.php';

// Make sure no one runs this from the web.
if (!Horde_CLI::runningFromCLI()) {
    exit("Must be run from the command line\n");
}

// Load the CLI environment - make sure there's no time limit, init
// some variables, etc.
Horde_CLI::init();

require_once 'Horde/DataTree.php';

class DataTreeObject_Bookmarks extends DataTreeObject {
    function DataTreeObject_Bookmarks($name)
    {
        parent::DataTreeObject($name);
        $this->data['bookmarks'] = array();
    }

    function _fromAttributes($attributes)
    {
        $bookmarks = array();
        foreach ($attributes as $attr) {
            if (substr($attr['name'], 0, 9) == 'bookmarks') {
                $bookmarks[substr($attr['name'], 10)][$attr['key']] = $attr['value'];
            } else {
                $this->data[$attr['name']] = $attr['value'];
            }
        }

        foreach ($bookmarks as $name => $properties) {
            $this->data['bookmarks'][$name] = $properties;
        }
    }

}

$datatree = &DataTree::factory('sql');
$db = &$datatree->_db;

$ids = $db->getAssoc('SELECT datatree_id, datatree_name, group_uid, user_uid from horde_datatree WHERE group_uid LIKE \'trean.bookmarks.%\'');
foreach ($ids as $id => $row) {

    // set the datatree group_uid
    $driver = $conf['datatree']['driver'];
    $trean_bookmarks->_datatree = &Datatree::singleton(
        $driver,
        array_merge(Horde::getDriverConfig('datatree', $driver), array('group' => 'trean.bookmarks.' . $row[2]))
    );

    // get the next bookmark category
    $datatree->_params['group'] = $row[1];
    $datatree->_load();
    $bookmarkOb = $datatree->getObject($row[0], 'DataTreeObject_Bookmarks');
    if (is_a($bookmarkOb, 'PEAR_Error')) {
        var_dump($bookmarkOb);
        exit;
    }

    // create new category
    echo 'Converting category: ' . $row[0] . "\n";
    if ($live) {
        $properties = array('name' => $row[0]);
        $category = &$trean_bookmarks->newCategory(md5(uniqid(mt_rand())), $properties);
        $trean_bookmarks->addCategory($category);
    }
    
    // add bookmarks
    foreach ($bookmarkOb->data as $bookmark_data) {
        foreach ($bookmark_data as $properties) {
            echo '  ' . $properties['name'] . "\n";
            $properties['title'] = $properties['name'];
            if ($live) {
                $category->addBookmark($properties);
            }
        }
    }

    // delete old category
    if ($live) {
        $datatree->remove($bookmarkOb);
    }
    
}

echo "Done!\n";

if (!$live) {
    echo "\nDidn't actually change any data. Edit this script and set \$live to true.\nBack up your database while you're at it.\n";
}